Class: DealMakerAPI::CreateJointProfileRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/DealMakerAPI/models/create_joint_profile_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateJointProfileRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 210

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DealMakerAPI::CreateJointProfileRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DealMakerAPI::CreateJointProfileRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'us_accredited_category')
    self.us_accredited_category = attributes[:'us_accredited_category']
  end

  if attributes.key?(:'joint_type')
    self.joint_type = attributes[:'joint_type']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'suffix')
    self.suffix = attributes[:'suffix']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'street_address')
    self.street_address = attributes[:'street_address']
  end

  if attributes.key?(:'unit2')
    self.unit2 = attributes[:'unit2']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'region')
    self.region = attributes[:'region']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'taxpayer_id')
    self.taxpayer_id = attributes[:'taxpayer_id']
  end

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'income')
    self.income = attributes[:'income']
  end

  if attributes.key?(:'net_worth')
    self.net_worth = attributes[:'net_worth']
  end

  if attributes.key?(:'reg_cf_prior_offerings_amount')
    self.reg_cf_prior_offerings_amount = attributes[:'reg_cf_prior_offerings_amount']
  end

  if attributes.key?(:'joint_holder_first_name')
    self.joint_holder_first_name = attributes[:'joint_holder_first_name']
  end

  if attributes.key?(:'joint_holder_last_name')
    self.joint_holder_last_name = attributes[:'joint_holder_last_name']
  end

  if attributes.key?(:'joint_holder_suffix')
    self.joint_holder_suffix = attributes[:'joint_holder_suffix']
  end

  if attributes.key?(:'joint_holder_country')
    self.joint_holder_country = attributes[:'joint_holder_country']
  end

  if attributes.key?(:'joint_holder_street_address')
    self.joint_holder_street_address = attributes[:'joint_holder_street_address']
  end

  if attributes.key?(:'joint_holder_unit2')
    self.joint_holder_unit2 = attributes[:'joint_holder_unit2']
  end

  if attributes.key?(:'joint_holder_city')
    self.joint_holder_city = attributes[:'joint_holder_city']
  end

  if attributes.key?(:'joint_holder_region')
    self.joint_holder_region = attributes[:'joint_holder_region']
  end

  if attributes.key?(:'joint_holder_postal_code')
    self.joint_holder_postal_code = attributes[:'joint_holder_postal_code']
  end

  if attributes.key?(:'joint_holder_date_of_birth')
    self.joint_holder_date_of_birth = attributes[:'joint_holder_date_of_birth']
  end

  if attributes.key?(:'joint_holder_taxpayer_id')
    self.joint_holder_taxpayer_id = attributes[:'joint_holder_taxpayer_id']
  end
end

Instance Attribute Details

#cityObject

The city of the primary holder (required).



46
47
48
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 46

def city
  @city
end

#countryObject

The country the primary holder (required).



37
38
39
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 37

def country
  @country
end

#date_of_birthObject

The date of birth of the primary holder (required).



55
56
57
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 55

def date_of_birth
  @date_of_birth
end

#emailObject

User email which is associated with investor profile.



19
20
21
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 19

def email
  @email
end

#first_nameObject

The first name of the primary holder (required).



28
29
30
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 28

def first_name
  @first_name
end

#incomeObject

The income of the primary holder.



64
65
66
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 64

def income
  @income
end

#joint_holder_cityObject

The city of the joint holder (required).



91
92
93
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 91

def joint_holder_city
  @joint_holder_city
end

#joint_holder_countryObject

The country of the joint holder (required).



82
83
84
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 82

def joint_holder_country
  @joint_holder_country
end

#joint_holder_date_of_birthObject

The date of birth of the joint holder (required).



100
101
102
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 100

def joint_holder_date_of_birth
  @joint_holder_date_of_birth
end

#joint_holder_first_nameObject

The first name of the joint holder (required).



73
74
75
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 73

def joint_holder_first_name
  @joint_holder_first_name
end

#joint_holder_last_nameObject

The last name of the joint holder (required).



76
77
78
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 76

def joint_holder_last_name
  @joint_holder_last_name
end

#joint_holder_postal_codeObject

The postal code or zipcode of the joint holder (required).



97
98
99
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 97

def joint_holder_postal_code
  @joint_holder_postal_code
end

#joint_holder_regionObject

The region or state of the joint holder (required).



94
95
96
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 94

def joint_holder_region
  @joint_holder_region
end

#joint_holder_street_addressObject

The street address of the joint holder (required).



85
86
87
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 85

def joint_holder_street_address
  @joint_holder_street_address
end

#joint_holder_suffixObject

The suffix of the joint holder.



79
80
81
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 79

def joint_holder_suffix
  @joint_holder_suffix
end

#joint_holder_taxpayer_idObject

The taxpayer identification number of the joint holder (required).



103
104
105
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 103

def joint_holder_taxpayer_id
  @joint_holder_taxpayer_id
end

#joint_holder_unit2Object

The street address line 2 of the joint holder.



88
89
90
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 88

def joint_holder_unit2
  @joint_holder_unit2
end

#joint_typeObject

The types of joint investor.



25
26
27
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 25

def joint_type
  @joint_type
end

#last_nameObject

The last name of the primary holder (required).



31
32
33
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 31

def last_name
  @last_name
end

#net_worthObject

The net worth of the primary holder.



67
68
69
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 67

def net_worth
  @net_worth
end

#phone_numberObject

The phone number of the primary holder (required).



61
62
63
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 61

def phone_number
  @phone_number
end

#postal_codeObject

The postal code or zipcode of the primary holder (required).



52
53
54
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 52

def postal_code
  @postal_code
end

#reg_cf_prior_offerings_amountObject

The prior offerings amount of the primary holder.



70
71
72
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 70

def reg_cf_prior_offerings_amount
  @reg_cf_prior_offerings_amount
end

#regionObject

The region or State of the primary holder (required).



49
50
51
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 49

def region
  @region
end

#street_addressObject

The street address of the primary holder (required).



40
41
42
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 40

def street_address
  @street_address
end

#suffixObject

The suffix of the primary holder.



34
35
36
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 34

def suffix
  @suffix
end

#taxpayer_idObject

The taxpayer identification number of the primary holder (required).



58
59
60
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 58

def taxpayer_id
  @taxpayer_id
end

#unit2Object

The street address line 2 of the primary holder.



43
44
45
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 43

def unit2
  @unit2
end

#us_accredited_categoryObject

The accredited investor information.



22
23
24
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 22

def us_accredited_category
  @us_accredited_category
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



163
164
165
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 163

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 128

def self.attribute_map
  {
    :'email' => :'email',
    :'us_accredited_category' => :'us_accredited_category',
    :'joint_type' => :'joint_type',
    :'first_name' => :'first_name',
    :'last_name' => :'last_name',
    :'suffix' => :'suffix',
    :'country' => :'country',
    :'street_address' => :'street_address',
    :'unit2' => :'unit2',
    :'city' => :'city',
    :'region' => :'region',
    :'postal_code' => :'postal_code',
    :'date_of_birth' => :'date_of_birth',
    :'taxpayer_id' => :'taxpayer_id',
    :'phone_number' => :'phone_number',
    :'income' => :'income',
    :'net_worth' => :'net_worth',
    :'reg_cf_prior_offerings_amount' => :'reg_cf_prior_offerings_amount',
    :'joint_holder_first_name' => :'joint_holder_first_name',
    :'joint_holder_last_name' => :'joint_holder_last_name',
    :'joint_holder_suffix' => :'joint_holder_suffix',
    :'joint_holder_country' => :'joint_holder_country',
    :'joint_holder_street_address' => :'joint_holder_street_address',
    :'joint_holder_unit2' => :'joint_holder_unit2',
    :'joint_holder_city' => :'joint_holder_city',
    :'joint_holder_region' => :'joint_holder_region',
    :'joint_holder_postal_code' => :'joint_holder_postal_code',
    :'joint_holder_date_of_birth' => :'joint_holder_date_of_birth',
    :'joint_holder_taxpayer_id' => :'joint_holder_taxpayer_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



433
434
435
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 433

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



203
204
205
206
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 203

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 168

def self.openapi_types
  {
    :'email' => :'String',
    :'us_accredited_category' => :'String',
    :'joint_type' => :'String',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'suffix' => :'String',
    :'country' => :'String',
    :'street_address' => :'String',
    :'unit2' => :'String',
    :'city' => :'String',
    :'region' => :'String',
    :'postal_code' => :'String',
    :'date_of_birth' => :'String',
    :'taxpayer_id' => :'String',
    :'phone_number' => :'String',
    :'income' => :'Float',
    :'net_worth' => :'Float',
    :'reg_cf_prior_offerings_amount' => :'Float',
    :'joint_holder_first_name' => :'String',
    :'joint_holder_last_name' => :'String',
    :'joint_holder_suffix' => :'String',
    :'joint_holder_country' => :'String',
    :'joint_holder_street_address' => :'String',
    :'joint_holder_unit2' => :'String',
    :'joint_holder_city' => :'String',
    :'joint_holder_region' => :'String',
    :'joint_holder_postal_code' => :'String',
    :'joint_holder_date_of_birth' => :'String',
    :'joint_holder_taxpayer_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 384

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      email == o.email &&
      us_accredited_category == o.us_accredited_category &&
      joint_type == o.joint_type &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      suffix == o.suffix &&
      country == o.country &&
      street_address == o.street_address &&
      unit2 == o.unit2 &&
      city == o.city &&
      region == o.region &&
      postal_code == o.postal_code &&
      date_of_birth == o.date_of_birth &&
      taxpayer_id == o.taxpayer_id &&
      phone_number == o.phone_number &&
      income == o.income &&
      net_worth == o.net_worth &&
      reg_cf_prior_offerings_amount == o.reg_cf_prior_offerings_amount &&
      joint_holder_first_name == o.joint_holder_first_name &&
      joint_holder_last_name == o.joint_holder_last_name &&
      joint_holder_suffix == o.joint_holder_suffix &&
      joint_holder_country == o.joint_holder_country &&
      joint_holder_street_address == o.joint_holder_street_address &&
      joint_holder_unit2 == o.joint_holder_unit2 &&
      joint_holder_city == o.joint_holder_city &&
      joint_holder_region == o.joint_holder_region &&
      joint_holder_postal_code == o.joint_holder_postal_code &&
      joint_holder_date_of_birth == o.joint_holder_date_of_birth &&
      joint_holder_taxpayer_id == o.joint_holder_taxpayer_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 464

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = DealMakerAPI.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 535

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 440

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


420
421
422
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 420

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



426
427
428
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 426

def hash
  [email, us_accredited_category, joint_type, first_name, last_name, suffix, country, street_address, unit2, city, region, postal_code, date_of_birth, taxpayer_id, phone_number, income, net_worth, reg_cf_prior_offerings_amount, joint_holder_first_name, joint_holder_last_name, joint_holder_suffix, joint_holder_country, joint_holder_street_address, joint_holder_unit2, joint_holder_city, joint_holder_region, joint_holder_postal_code, joint_holder_date_of_birth, joint_holder_taxpayer_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



342
343
344
345
346
347
348
349
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 342

def list_invalid_properties
  invalid_properties = Array.new
  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



511
512
513
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 511

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



517
518
519
520
521
522
523
524
525
526
527
528
529
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 517

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



505
506
507
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 505

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



353
354
355
356
357
358
359
360
# File 'lib/DealMakerAPI/models/create_joint_profile_request.rb', line 353

def valid?
  return false if @email.nil?
  us_accredited_category_validator = EnumAttributeValidator.new('String', ["income_individual", "assets_individual", "director", "knowledgable_employee", "broker_or_dealer", "investment_advisor_registered", "investment_advisor_relying", "designated_accredited_investor", "not_accredited"])
  return false unless us_accredited_category_validator.valid?(@us_accredited_category)
  joint_type_validator = EnumAttributeValidator.new('String', ["joint_tenant", "tenants_in_common", "community_property"])
  return false unless joint_type_validator.valid?(@joint_type)
  true
end