Class: DealMakerAPI::PatchIndividualProfileRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/DealMakerAPI/models/patch_individual_profile_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PatchIndividualProfileRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 150

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DealMakerAPI::PatchIndividualProfileRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DealMakerAPI::PatchIndividualProfileRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'us_accredited_category')
    self.us_accredited_category = attributes[:'us_accredited_category']
  end

  if attributes.key?(:'ca_accredited_investor')
    self.ca_accredited_investor = attributes[:'ca_accredited_investor']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'suffix')
    self.suffix = attributes[:'suffix']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'taxpayer_id')
    self.taxpayer_id = attributes[:'taxpayer_id']
  end

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'street_address')
    self.street_address = attributes[:'street_address']
  end

  if attributes.key?(:'unit2')
    self.unit2 = attributes[:'unit2']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'region')
    self.region = attributes[:'region']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'income')
    self.income = attributes[:'income']
  end

  if attributes.key?(:'net_worth')
    self.net_worth = attributes[:'net_worth']
  end

  if attributes.key?(:'reg_cf_prior_offerings_amount')
    self.reg_cf_prior_offerings_amount = attributes[:'reg_cf_prior_offerings_amount']
  end
end

Instance Attribute Details

#ca_accredited_investorObject

The Canadian accredited investor information.



22
23
24
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 22

def ca_accredited_investor
  @ca_accredited_investor
end

#cityObject

The city of the individual investor profile.



52
53
54
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 52

def city
  @city
end

#countryObject

The country of the individual investor profile.



43
44
45
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 43

def country
  @country
end

#date_of_birthObject

The date of birth of the investor profile.



34
35
36
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 34

def date_of_birth
  @date_of_birth
end

#first_nameObject

The first name of the individual investor profile.



25
26
27
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 25

def first_name
  @first_name
end

#incomeObject

The income of the individual investor profile



61
62
63
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 61

def income
  @income
end

#last_nameObject

The last name of the individual investor profile.



28
29
30
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 28

def last_name
  @last_name
end

#net_worthObject

The net worth of the individual investor profile



64
65
66
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 64

def net_worth
  @net_worth
end

#phone_numberObject

The phone number of the investor profile.



40
41
42
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 40

def phone_number
  @phone_number
end

#postal_codeObject

The postal code or zipcode of the individual investor profile.



58
59
60
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 58

def postal_code
  @postal_code
end

#reg_cf_prior_offerings_amountObject

The prior offering amount of the individual investor profile



67
68
69
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 67

def reg_cf_prior_offerings_amount
  @reg_cf_prior_offerings_amount
end

#regionObject

The region or state of the individual investor profile.



55
56
57
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 55

def region
  @region
end

#street_addressObject

The street address of the individual investor profile.



46
47
48
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 46

def street_address
  @street_address
end

#suffixObject

The suffix of the individual investor profile.



31
32
33
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 31

def suffix
  @suffix
end

#taxpayer_idObject

The taxpayer identification number of the investor profile.



37
38
39
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 37

def taxpayer_id
  @taxpayer_id
end

#unit2Object

The street address line 2 of the individual investor profile.



49
50
51
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 49

def unit2
  @unit2
end

#us_accredited_categoryObject

The United States accredited investor information.



19
20
21
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 19

def us_accredited_category
  @us_accredited_category
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 334

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = DealMakerAPI.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



115
116
117
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 115

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 92

def self.attribute_map
  {
    :'us_accredited_category' => :'us_accredited_category',
    :'ca_accredited_investor' => :'ca_accredited_investor',
    :'first_name' => :'first_name',
    :'last_name' => :'last_name',
    :'suffix' => :'suffix',
    :'date_of_birth' => :'date_of_birth',
    :'taxpayer_id' => :'taxpayer_id',
    :'phone_number' => :'phone_number',
    :'country' => :'country',
    :'street_address' => :'street_address',
    :'unit2' => :'unit2',
    :'city' => :'city',
    :'region' => :'region',
    :'postal_code' => :'postal_code',
    :'income' => :'income',
    :'net_worth' => :'net_worth',
    :'reg_cf_prior_offerings_amount' => :'reg_cf_prior_offerings_amount'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 310

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



143
144
145
146
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 143

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 120

def self.openapi_types
  {
    :'us_accredited_category' => :'String',
    :'ca_accredited_investor' => :'String',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'suffix' => :'String',
    :'date_of_birth' => :'String',
    :'taxpayer_id' => :'String',
    :'phone_number' => :'String',
    :'country' => :'String',
    :'street_address' => :'String',
    :'unit2' => :'String',
    :'city' => :'String',
    :'region' => :'String',
    :'postal_code' => :'String',
    :'income' => :'Float',
    :'net_worth' => :'Float',
    :'reg_cf_prior_offerings_amount' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 273

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      us_accredited_category == o.us_accredited_category &&
      ca_accredited_investor == o.ca_accredited_investor &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      suffix == o.suffix &&
      date_of_birth == o.date_of_birth &&
      taxpayer_id == o.taxpayer_id &&
      phone_number == o.phone_number &&
      country == o.country &&
      street_address == o.street_address &&
      unit2 == o.unit2 &&
      city == o.city &&
      region == o.region &&
      postal_code == o.postal_code &&
      income == o.income &&
      net_worth == o.net_worth &&
      reg_cf_prior_offerings_amount == o.reg_cf_prior_offerings_amount
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 405

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


297
298
299
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 297

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



303
304
305
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 303

def hash
  [us_accredited_category, ca_accredited_investor, first_name, last_name, suffix, date_of_birth, taxpayer_id, phone_number, country, street_address, unit2, city, region, postal_code, income, net_worth, reg_cf_prior_offerings_amount].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



234
235
236
237
238
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 234

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



381
382
383
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 381

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



387
388
389
390
391
392
393
394
395
396
397
398
399
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 387

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



375
376
377
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 375

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



242
243
244
245
246
247
248
249
# File 'lib/DealMakerAPI/models/patch_individual_profile_request.rb', line 242

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  us_accredited_category_validator = EnumAttributeValidator.new('String', ["income_individual", "assets_individual", "director", "knowledgable_employee", "broker_or_dealer", "investment_advisor_registered", "investment_advisor_relying", "designated_accredited_investor", "not_accredited"])
  return false unless us_accredited_category_validator.valid?(@us_accredited_category)
  ca_accredited_investor_validator = EnumAttributeValidator.new('String', ["d", "e", "e_1", "j", "j_1", "k", "l", "q", "v", "x"])
  return false unless ca_accredited_investor_validator.valid?(@ca_accredited_investor)
  true
end