Class: DealMakerAPI::UserApi
- Inherits:
-
Object
- Object
- DealMakerAPI::UserApi
- Defined in:
- lib/DealMakerAPI/api/user_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_factor(id, opts = {}) ⇒ V1EntitiesUsersFactor
Creates an API endpoint for creating a new TOTP factor Create an API endpoint for creating a new TOTP factor.
-
#create_factor_with_http_info(id, opts = {}) ⇒ Array<(V1EntitiesUsersFactor, Integer, Hash)>
Creates an API endpoint for creating a new TOTP factor Create an API endpoint for creating a new TOTP factor.
-
#delete_channel(id, channel, opts = {}) ⇒ V1EntitiesDeleteResult
Creates an API endpoint to delete a specific two factor channel" Create an API endpoint to delete a specific two factor channel.
-
#delete_channel_with_http_info(id, channel, opts = {}) ⇒ Array<(V1EntitiesDeleteResult, Integer, Hash)>
Creates an API endpoint to delete a specific two factor channel" Create an API endpoint to delete a specific two factor channel.
-
#disable_mfa(id, opts = {}) ⇒ nil
Disable all the multi-factor authentication integrations for a user Disable all the multi-factor authentication integrations for a user.
-
#disable_mfa_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Disable all the multi-factor authentication integrations for a user Disable all the multi-factor authentication integrations for a user.
-
#get_two_factor_channels(id, opts = {}) ⇒ V1EntitiesUsersTwoFactorChannels
Creates an API endpoint to return a list of existing TOTP factor Create an API endpoint to return a list of existing TOTP factor.
-
#get_two_factor_channels_with_http_info(id, opts = {}) ⇒ Array<(V1EntitiesUsersTwoFactorChannels, Integer, Hash)>
Creates an API endpoint to return a list of existing TOTP factor Create an API endpoint to return a list of existing TOTP factor.
-
#get_user(id, opts = {}) ⇒ V1EntitiesUser
Get user by User ID Get a single user using the User ID.
-
#get_user_with_http_info(id, opts = {}) ⇒ Array<(V1EntitiesUser, Integer, Hash)>
Get user by User ID Get a single user using the User ID.
-
#get_verification_resources(login_token, opts = {}) ⇒ V1EntitiesUsersVerificationResources
Gets the verification process resources Get verification process resources.
-
#get_verification_resources_with_http_info(login_token, opts = {}) ⇒ Array<(V1EntitiesUsersVerificationResources, Integer, Hash)>
Gets the verification process resources Get verification process resources.
-
#initialize(api_client = ApiClient.default) ⇒ UserApi
constructor
A new instance of UserApi.
-
#send_verification_code(send_verification_code_request, opts = {}) ⇒ V1EntitiesDeleteResult
Sends the verification code to the user Send the verification code to the user.
-
#send_verification_code_with_http_info(send_verification_code_request, opts = {}) ⇒ Array<(V1EntitiesDeleteResult, Integer, Hash)>
Sends the verification code to the user Send the verification code to the user.
-
#setup_sms_verification(id, setup_sms_verification_request, opts = {}) ⇒ nil
Start a setup for a SMS Verification by creating a two factor channel of sms type Start a setup for a SMS Verification by creating a two factor channel of sms type.
-
#setup_sms_verification_with_http_info(id, setup_sms_verification_request, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Start a setup for a SMS Verification by creating a two factor channel of sms type Start a setup for a SMS Verification by creating a two factor channel of sms type.
-
#update_user_password(id, update_user_password_request, opts = {}) ⇒ V1EntitiesUser
Update user password Update user password.
-
#update_user_password_with_http_info(id, update_user_password_request, opts = {}) ⇒ Array<(V1EntitiesUser, Integer, Hash)>
Update user password Update user password.
-
#verify_factor(id, verify_factor_request, opts = {}) ⇒ V1EntitiesUsersTwoFactorChannel
Creates an API endpoint to verify an existing TOTP factor Create an API endpoint to verify an existing TOTP factor.
-
#verify_factor_with_http_info(id, verify_factor_request, opts = {}) ⇒ Array<(V1EntitiesUsersTwoFactorChannel, Integer, Hash)>
Creates an API endpoint to verify an existing TOTP factor Create an API endpoint to verify an existing TOTP factor.
-
#verify_sms_verification(id, verify_sms_verification_request, opts = {}) ⇒ V1EntitiesUsersTwoFactorChannel
Verify a SMS Verification by creating a two factor channel of sms type Verify a SMS Verification by creating a two factor channel of sms type.
-
#verify_sms_verification_with_http_info(id, verify_sms_verification_request, opts = {}) ⇒ Array<(V1EntitiesUsersTwoFactorChannel, Integer, Hash)>
Verify a SMS Verification by creating a two factor channel of sms type Verify a SMS Verification by creating a two factor channel of sms type.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_factor(id, opts = {}) ⇒ V1EntitiesUsersFactor
Creates an API endpoint for creating a new TOTP factor Create an API endpoint for creating a new TOTP factor
27 28 29 30 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 27 def create_factor(id, opts = {}) data, _status_code, _headers = create_factor_with_http_info(id, opts) data end |
#create_factor_with_http_info(id, opts = {}) ⇒ Array<(V1EntitiesUsersFactor, Integer, Hash)>
Creates an API endpoint for creating a new TOTP factor Create an API endpoint for creating a new TOTP factor
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 37 def create_factor_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.create_factor ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling UserApi.create_factor" end # resource path local_var_path = '/users/{id}/create_factor'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1EntitiesUsersFactor' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.create_factor", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#create_factor\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_channel(id, channel, opts = {}) ⇒ V1EntitiesDeleteResult
Creates an API endpoint to delete a specific two factor channel" Create an API endpoint to delete a specific two factor channel
91 92 93 94 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 91 def delete_channel(id, channel, opts = {}) data, _status_code, _headers = delete_channel_with_http_info(id, channel, opts) data end |
#delete_channel_with_http_info(id, channel, opts = {}) ⇒ Array<(V1EntitiesDeleteResult, Integer, Hash)>
Creates an API endpoint to delete a specific two factor channel" Create an API endpoint to delete a specific two factor channel
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 102 def delete_channel_with_http_info(id, channel, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.delete_channel ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling UserApi.delete_channel" end # verify the required parameter 'channel' is set if @api_client.config.client_side_validation && channel.nil? fail ArgumentError, "Missing the required parameter 'channel' when calling UserApi.delete_channel" end # resource path local_var_path = '/users/{id}/two_factor_channels/delete/{channel}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)).sub('{' + 'channel' + '}', CGI.escape(channel.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1EntitiesDeleteResult' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.delete_channel", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#delete_channel\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#disable_mfa(id, opts = {}) ⇒ nil
Disable all the multi-factor authentication integrations for a user Disable all the multi-factor authentication integrations for a user
159 160 161 162 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 159 def disable_mfa(id, opts = {}) disable_mfa_with_http_info(id, opts) nil end |
#disable_mfa_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Disable all the multi-factor authentication integrations for a user Disable all the multi-factor authentication integrations for a user
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 169 def disable_mfa_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.disable_mfa ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling UserApi.disable_mfa" end # resource path local_var_path = '/users/{id}/disable_mfa'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.disable_mfa", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#disable_mfa\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_two_factor_channels(id, opts = {}) ⇒ V1EntitiesUsersTwoFactorChannels
Creates an API endpoint to return a list of existing TOTP factor Create an API endpoint to return a list of existing TOTP factor
220 221 222 223 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 220 def get_two_factor_channels(id, opts = {}) data, _status_code, _headers = get_two_factor_channels_with_http_info(id, opts) data end |
#get_two_factor_channels_with_http_info(id, opts = {}) ⇒ Array<(V1EntitiesUsersTwoFactorChannels, Integer, Hash)>
Creates an API endpoint to return a list of existing TOTP factor Create an API endpoint to return a list of existing TOTP factor
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 230 def get_two_factor_channels_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.get_two_factor_channels ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling UserApi.get_two_factor_channels" end # resource path local_var_path = '/users/{id}/two_factor_channels'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1EntitiesUsersTwoFactorChannels' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.get_two_factor_channels", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#get_two_factor_channels\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_user(id, opts = {}) ⇒ V1EntitiesUser
Get user by User ID Get a single user using the User ID
283 284 285 286 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 283 def get_user(id, opts = {}) data, _status_code, _headers = get_user_with_http_info(id, opts) data end |
#get_user_with_http_info(id, opts = {}) ⇒ Array<(V1EntitiesUser, Integer, Hash)>
Get user by User ID Get a single user using the User ID
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 293 def get_user_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.get_user ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling UserApi.get_user" end # resource path local_var_path = '/users/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1EntitiesUser' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.get_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#get_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_verification_resources(login_token, opts = {}) ⇒ V1EntitiesUsersVerificationResources
Gets the verification process resources Get verification process resources
346 347 348 349 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 346 def get_verification_resources(login_token, opts = {}) data, _status_code, _headers = get_verification_resources_with_http_info(login_token, opts) data end |
#get_verification_resources_with_http_info(login_token, opts = {}) ⇒ Array<(V1EntitiesUsersVerificationResources, Integer, Hash)>
Gets the verification process resources Get verification process resources
356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 356 def get_verification_resources_with_http_info(login_token, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.get_verification_resources ...' end # verify the required parameter 'login_token' is set if @api_client.config.client_side_validation && login_token.nil? fail ArgumentError, "Missing the required parameter 'login_token' when calling UserApi.get_verification_resources" end # resource path local_var_path = '/users/verification/resources' # query parameters query_params = opts[:query_params] || {} query_params[:'login_token'] = login_token # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1EntitiesUsersVerificationResources' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.get_verification_resources", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#get_verification_resources\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#send_verification_code(send_verification_code_request, opts = {}) ⇒ V1EntitiesDeleteResult
Sends the verification code to the user Send the verification code to the user
410 411 412 413 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 410 def send_verification_code(send_verification_code_request, opts = {}) data, _status_code, _headers = send_verification_code_with_http_info(send_verification_code_request, opts) data end |
#send_verification_code_with_http_info(send_verification_code_request, opts = {}) ⇒ Array<(V1EntitiesDeleteResult, Integer, Hash)>
Sends the verification code to the user Send the verification code to the user
420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 420 def send_verification_code_with_http_info(send_verification_code_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.send_verification_code ...' end # verify the required parameter 'send_verification_code_request' is set if @api_client.config.client_side_validation && send_verification_code_request.nil? fail ArgumentError, "Missing the required parameter 'send_verification_code_request' when calling UserApi.send_verification_code" end # resource path local_var_path = '/users/verification/send_code' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(send_verification_code_request) # return_type return_type = opts[:debug_return_type] || 'V1EntitiesDeleteResult' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.send_verification_code", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#send_verification_code\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#setup_sms_verification(id, setup_sms_verification_request, opts = {}) ⇒ nil
Start a setup for a SMS Verification by creating a two factor channel of sms type Start a setup for a SMS Verification by creating a two factor channel of sms type
479 480 481 482 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 479 def setup_sms_verification(id, setup_sms_verification_request, opts = {}) setup_sms_verification_with_http_info(id, setup_sms_verification_request, opts) nil end |
#setup_sms_verification_with_http_info(id, setup_sms_verification_request, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Start a setup for a SMS Verification by creating a two factor channel of sms type Start a setup for a SMS Verification by creating a two factor channel of sms type
490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 490 def setup_sms_verification_with_http_info(id, setup_sms_verification_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.setup_sms_verification ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling UserApi.setup_sms_verification" end # verify the required parameter 'setup_sms_verification_request' is set if @api_client.config.client_side_validation && setup_sms_verification_request.nil? fail ArgumentError, "Missing the required parameter 'setup_sms_verification_request' when calling UserApi.setup_sms_verification" end # resource path local_var_path = '/users/{id}/setup_sms_verification'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(setup_sms_verification_request) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.setup_sms_verification", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#setup_sms_verification\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_user_password(id, update_user_password_request, opts = {}) ⇒ V1EntitiesUser
Update user password Update user password
551 552 553 554 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 551 def update_user_password(id, update_user_password_request, opts = {}) data, _status_code, _headers = update_user_password_with_http_info(id, update_user_password_request, opts) data end |
#update_user_password_with_http_info(id, update_user_password_request, opts = {}) ⇒ Array<(V1EntitiesUser, Integer, Hash)>
Update user password Update user password
562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 562 def update_user_password_with_http_info(id, update_user_password_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.update_user_password ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling UserApi.update_user_password" end # verify the required parameter 'update_user_password_request' is set if @api_client.config.client_side_validation && update_user_password_request.nil? fail ArgumentError, "Missing the required parameter 'update_user_password_request' when calling UserApi.update_user_password" end # resource path local_var_path = '/users/{id}/update_password'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_user_password_request) # return_type return_type = opts[:debug_return_type] || 'V1EntitiesUser' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.update_user_password", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#update_user_password\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#verify_factor(id, verify_factor_request, opts = {}) ⇒ V1EntitiesUsersTwoFactorChannel
Creates an API endpoint to verify an existing TOTP factor Create an API endpoint to verify an existing TOTP factor
625 626 627 628 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 625 def verify_factor(id, verify_factor_request, opts = {}) data, _status_code, _headers = verify_factor_with_http_info(id, verify_factor_request, opts) data end |
#verify_factor_with_http_info(id, verify_factor_request, opts = {}) ⇒ Array<(V1EntitiesUsersTwoFactorChannel, Integer, Hash)>
Creates an API endpoint to verify an existing TOTP factor Create an API endpoint to verify an existing TOTP factor
636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 636 def verify_factor_with_http_info(id, verify_factor_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.verify_factor ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling UserApi.verify_factor" end # verify the required parameter 'verify_factor_request' is set if @api_client.config.client_side_validation && verify_factor_request.nil? fail ArgumentError, "Missing the required parameter 'verify_factor_request' when calling UserApi.verify_factor" end # resource path local_var_path = '/users/{id}/verify_factor'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(verify_factor_request) # return_type return_type = opts[:debug_return_type] || 'V1EntitiesUsersTwoFactorChannel' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.verify_factor", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#verify_factor\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#verify_sms_verification(id, verify_sms_verification_request, opts = {}) ⇒ V1EntitiesUsersTwoFactorChannel
Verify a SMS Verification by creating a two factor channel of sms type Verify a SMS Verification by creating a two factor channel of sms type
699 700 701 702 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 699 def verify_sms_verification(id, verify_sms_verification_request, opts = {}) data, _status_code, _headers = verify_sms_verification_with_http_info(id, verify_sms_verification_request, opts) data end |
#verify_sms_verification_with_http_info(id, verify_sms_verification_request, opts = {}) ⇒ Array<(V1EntitiesUsersTwoFactorChannel, Integer, Hash)>
Verify a SMS Verification by creating a two factor channel of sms type Verify a SMS Verification by creating a two factor channel of sms type
710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 710 def verify_sms_verification_with_http_info(id, verify_sms_verification_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.verify_sms_verification ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling UserApi.verify_sms_verification" end # verify the required parameter 'verify_sms_verification_request' is set if @api_client.config.client_side_validation && verify_sms_verification_request.nil? fail ArgumentError, "Missing the required parameter 'verify_sms_verification_request' when calling UserApi.verify_sms_verification" end # resource path local_var_path = '/users/{id}/verify_sms_verification'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(verify_sms_verification_request) # return_type return_type = opts[:debug_return_type] || 'V1EntitiesUsersTwoFactorChannel' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.verify_sms_verification", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#verify_sms_verification\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |