Class: DealMakerAPI::DealsApi
- Inherits:
-
Object
- Object
- DealMakerAPI::DealsApi
- Defined in:
- lib/DealMakerAPI/api/deals_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ DealsApi
constructor
A new instance of DealsApi.
-
#post_deals_id_email_campaign_email_campaign_id_send_email(id, email_campaign_id, opts = {}) ⇒ nil
Send emails to all the investors invited to the material change campaign Send material campaign emails.
-
#post_deals_id_email_campaign_email_campaign_id_send_email_with_http_info(id, email_campaign_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Send emails to all the investors invited to the material change campaign Send material campaign emails.
-
#put_deals_id_script_tag_environment(id, put_deals_id_script_tag_environment_request, opts = {}) ⇒ nil
Update script tag environment for the deal.
-
#put_deals_id_script_tag_environment_with_http_info(id, put_deals_id_script_tag_environment_request, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update script tag environment for the deal.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ DealsApi
Returns a new instance of DealsApi.
19 20 21 |
# File 'lib/DealMakerAPI/api/deals_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/DealMakerAPI/api/deals_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#post_deals_id_email_campaign_email_campaign_id_send_email(id, email_campaign_id, opts = {}) ⇒ nil
Send emails to all the investors invited to the material change campaign Send material campaign emails
28 29 30 31 |
# File 'lib/DealMakerAPI/api/deals_api.rb', line 28 def post_deals_id_email_campaign_email_campaign_id_send_email(id, email_campaign_id, opts = {}) post_deals_id_email_campaign_email_campaign_id_send_email_with_http_info(id, email_campaign_id, opts) nil end |
#post_deals_id_email_campaign_email_campaign_id_send_email_with_http_info(id, email_campaign_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Send emails to all the investors invited to the material change campaign Send material campaign emails
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/DealMakerAPI/api/deals_api.rb', line 39 def post_deals_id_email_campaign_email_campaign_id_send_email_with_http_info(id, email_campaign_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DealsApi.post_deals_id_email_campaign_email_campaign_id_send_email ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling DealsApi.post_deals_id_email_campaign_email_campaign_id_send_email" end # verify the required parameter 'email_campaign_id' is set if @api_client.config.client_side_validation && email_campaign_id.nil? fail ArgumentError, "Missing the required parameter 'email_campaign_id' when calling DealsApi.post_deals_id_email_campaign_email_campaign_id_send_email" end # resource path local_var_path = '/deals/{id}/email_campaign/{email_campaign_id}/send_email'.sub('{' + 'id' + '}', CGI.escape(id.to_s)).sub('{' + 'email_campaign_id' + '}', CGI.escape(email_campaign_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"DealsApi.post_deals_id_email_campaign_email_campaign_id_send_email", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DealsApi#post_deals_id_email_campaign_email_campaign_id_send_email\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#put_deals_id_script_tag_environment(id, put_deals_id_script_tag_environment_request, opts = {}) ⇒ nil
Update script tag environment for the deal. Update script tag environment for the deal.
95 96 97 98 |
# File 'lib/DealMakerAPI/api/deals_api.rb', line 95 def put_deals_id_script_tag_environment(id, put_deals_id_script_tag_environment_request, opts = {}) put_deals_id_script_tag_environment_with_http_info(id, put_deals_id_script_tag_environment_request, opts) nil end |
#put_deals_id_script_tag_environment_with_http_info(id, put_deals_id_script_tag_environment_request, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update script tag environment for the deal. Update script tag environment for the deal.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/DealMakerAPI/api/deals_api.rb', line 106 def put_deals_id_script_tag_environment_with_http_info(id, put_deals_id_script_tag_environment_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DealsApi.put_deals_id_script_tag_environment ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling DealsApi.put_deals_id_script_tag_environment" end # verify the required parameter 'put_deals_id_script_tag_environment_request' is set if @api_client.config.client_side_validation && put_deals_id_script_tag_environment_request.nil? fail ArgumentError, "Missing the required parameter 'put_deals_id_script_tag_environment_request' when calling DealsApi.put_deals_id_script_tag_environment" end # resource path local_var_path = '/deals/{id}/script_tag_environment'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(put_deals_id_script_tag_environment_request) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"DealsApi.put_deals_id_script_tag_environment", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DealsApi#put_deals_id_script_tag_environment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |