Class: DealMakerAPI::PatchTrustProfileRequest
- Inherits:
-
Object
- Object
- DealMakerAPI::PatchTrustProfileRequest
- Defined in:
- lib/DealMakerAPI/models/patch_trust_profile_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ca_accredited_investor ⇒ Object
The Canadian accredited investor information.
-
#city ⇒ Object
Trust city.
-
#country ⇒ Object
Trust country.
-
#date ⇒ Object
The creation date of the trust.
-
#income ⇒ Object
The income of the Trust.
-
#name ⇒ Object
The name of the trust.
-
#net_worth ⇒ Object
The net worth of the Trust.
-
#phone_number ⇒ Object
The phone number of the trust.
-
#postal_code ⇒ Object
Trust postal code or zipcode.
-
#reg_cf_prior_offerings_amount ⇒ Object
The prior offering amount of the Trust.
-
#region ⇒ Object
Trust region or state.
-
#street_address ⇒ Object
Trust street address.
-
#trustee_city ⇒ Object
Trustee city.
-
#trustee_country ⇒ Object
Trustee country.
-
#trustee_date_of_birth ⇒ Object
Trustee date of birth.
-
#trustee_first_name ⇒ Object
Trustee first name.
-
#trustee_last_name ⇒ Object
Trustee last name.
-
#trustee_postal_code ⇒ Object
Trustee postal code or zipcode.
-
#trustee_region ⇒ Object
Trustee region or state.
-
#trustee_street_address ⇒ Object
Trustee street address.
-
#trustee_suffix ⇒ Object
Trustee suffix.
-
#trustee_taxpayer_id ⇒ Object
The taxpayer identification number of the investor profile.
-
#trustee_unit2 ⇒ Object
Trustee street address line 2.
-
#unit2 ⇒ Object
Trust street address line 2.
-
#us_accredited_category ⇒ Object
The United States accredited investor information.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchTrustProfileRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PatchTrustProfileRequest
Initializes the object
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 190 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DealMakerAPI::PatchTrustProfileRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DealMakerAPI::PatchTrustProfileRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'us_accredited_category') self.us_accredited_category = attributes[:'us_accredited_category'] end if attributes.key?(:'ca_accredited_investor') self.ca_accredited_investor = attributes[:'ca_accredited_investor'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'date') self.date = attributes[:'date'] end if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'street_address') self.street_address = attributes[:'street_address'] end if attributes.key?(:'unit2') self.unit2 = attributes[:'unit2'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'region') self.region = attributes[:'region'] end if attributes.key?(:'postal_code') self.postal_code = attributes[:'postal_code'] end if attributes.key?(:'income') self.income = attributes[:'income'] end if attributes.key?(:'net_worth') self.net_worth = attributes[:'net_worth'] end if attributes.key?(:'reg_cf_prior_offerings_amount') self.reg_cf_prior_offerings_amount = attributes[:'reg_cf_prior_offerings_amount'] end if attributes.key?(:'trustee_first_name') self.trustee_first_name = attributes[:'trustee_first_name'] end if attributes.key?(:'trustee_last_name') self.trustee_last_name = attributes[:'trustee_last_name'] end if attributes.key?(:'trustee_suffix') self.trustee_suffix = attributes[:'trustee_suffix'] end if attributes.key?(:'trustee_country') self.trustee_country = attributes[:'trustee_country'] end if attributes.key?(:'trustee_street_address') self.trustee_street_address = attributes[:'trustee_street_address'] end if attributes.key?(:'trustee_unit2') self.trustee_unit2 = attributes[:'trustee_unit2'] end if attributes.key?(:'trustee_city') self.trustee_city = attributes[:'trustee_city'] end if attributes.key?(:'trustee_region') self.trustee_region = attributes[:'trustee_region'] end if attributes.key?(:'trustee_postal_code') self.trustee_postal_code = attributes[:'trustee_postal_code'] end if attributes.key?(:'trustee_date_of_birth') self.trustee_date_of_birth = attributes[:'trustee_date_of_birth'] end if attributes.key?(:'trustee_taxpayer_id') self.trustee_taxpayer_id = attributes[:'trustee_taxpayer_id'] end end |
Instance Attribute Details
#ca_accredited_investor ⇒ Object
The Canadian accredited investor information.
22 23 24 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 22 def ca_accredited_investor @ca_accredited_investor end |
#city ⇒ Object
Trust city.
43 44 45 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 43 def city @city end |
#country ⇒ Object
Trust country.
34 35 36 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 34 def country @country end |
#date ⇒ Object
The creation date of the trust.
28 29 30 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 28 def date @date end |
#income ⇒ Object
The income of the Trust.
52 53 54 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 52 def income @income end |
#name ⇒ Object
The name of the trust.
25 26 27 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 25 def name @name end |
#net_worth ⇒ Object
The net worth of the Trust.
55 56 57 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 55 def net_worth @net_worth end |
#phone_number ⇒ Object
The phone number of the trust.
31 32 33 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 31 def phone_number @phone_number end |
#postal_code ⇒ Object
Trust postal code or zipcode.
49 50 51 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 49 def postal_code @postal_code end |
#reg_cf_prior_offerings_amount ⇒ Object
The prior offering amount of the Trust.
58 59 60 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 58 def reg_cf_prior_offerings_amount @reg_cf_prior_offerings_amount end |
#region ⇒ Object
Trust region or state.
46 47 48 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 46 def region @region end |
#street_address ⇒ Object
Trust street address.
37 38 39 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 37 def street_address @street_address end |
#trustee_city ⇒ Object
Trustee city.
79 80 81 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 79 def trustee_city @trustee_city end |
#trustee_country ⇒ Object
Trustee country.
70 71 72 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 70 def trustee_country @trustee_country end |
#trustee_date_of_birth ⇒ Object
Trustee date of birth.
88 89 90 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 88 def trustee_date_of_birth @trustee_date_of_birth end |
#trustee_first_name ⇒ Object
Trustee first name.
61 62 63 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 61 def trustee_first_name @trustee_first_name end |
#trustee_last_name ⇒ Object
Trustee last name.
64 65 66 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 64 def trustee_last_name @trustee_last_name end |
#trustee_postal_code ⇒ Object
Trustee postal code or zipcode.
85 86 87 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 85 def trustee_postal_code @trustee_postal_code end |
#trustee_region ⇒ Object
Trustee region or state.
82 83 84 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 82 def trustee_region @trustee_region end |
#trustee_street_address ⇒ Object
Trustee street address.
73 74 75 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 73 def trustee_street_address @trustee_street_address end |
#trustee_suffix ⇒ Object
Trustee suffix.
67 68 69 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 67 def trustee_suffix @trustee_suffix end |
#trustee_taxpayer_id ⇒ Object
The taxpayer identification number of the investor profile.
91 92 93 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 91 def trustee_taxpayer_id @trustee_taxpayer_id end |
#trustee_unit2 ⇒ Object
Trustee street address line 2.
76 77 78 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 76 def trustee_unit2 @trustee_unit2 end |
#unit2 ⇒ Object
Trust street address line 2.
40 41 42 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 40 def unit2 @unit2 end |
#us_accredited_category ⇒ Object
The United States accredited investor information.
19 20 21 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 19 def us_accredited_category @us_accredited_category end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 414 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = DealMakerAPI.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
147 148 149 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 147 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 116 def self.attribute_map { :'us_accredited_category' => :'us_accredited_category', :'ca_accredited_investor' => :'ca_accredited_investor', :'name' => :'name', :'date' => :'date', :'phone_number' => :'phone_number', :'country' => :'country', :'street_address' => :'street_address', :'unit2' => :'unit2', :'city' => :'city', :'region' => :'region', :'postal_code' => :'postal_code', :'income' => :'income', :'net_worth' => :'net_worth', :'reg_cf_prior_offerings_amount' => :'reg_cf_prior_offerings_amount', :'trustee_first_name' => :'trustee_first_name', :'trustee_last_name' => :'trustee_last_name', :'trustee_suffix' => :'trustee_suffix', :'trustee_country' => :'trustee_country', :'trustee_street_address' => :'trustee_street_address', :'trustee_unit2' => :'trustee_unit2', :'trustee_city' => :'trustee_city', :'trustee_region' => :'trustee_region', :'trustee_postal_code' => :'trustee_postal_code', :'trustee_date_of_birth' => :'trustee_date_of_birth', :'trustee_taxpayer_id' => :'trustee_taxpayer_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 390 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
183 184 185 186 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 183 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 152 def self.openapi_types { :'us_accredited_category' => :'String', :'ca_accredited_investor' => :'String', :'name' => :'String', :'date' => :'String', :'phone_number' => :'String', :'country' => :'String', :'street_address' => :'String', :'unit2' => :'String', :'city' => :'String', :'region' => :'String', :'postal_code' => :'String', :'income' => :'Float', :'net_worth' => :'Float', :'reg_cf_prior_offerings_amount' => :'Float', :'trustee_first_name' => :'String', :'trustee_last_name' => :'String', :'trustee_suffix' => :'String', :'trustee_country' => :'String', :'trustee_street_address' => :'String', :'trustee_unit2' => :'String', :'trustee_city' => :'String', :'trustee_region' => :'String', :'trustee_postal_code' => :'String', :'trustee_date_of_birth' => :'String', :'trustee_taxpayer_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 345 def ==(o) return true if self.equal?(o) self.class == o.class && us_accredited_category == o.us_accredited_category && ca_accredited_investor == o.ca_accredited_investor && name == o.name && date == o.date && phone_number == o.phone_number && country == o.country && street_address == o.street_address && unit2 == o.unit2 && city == o.city && region == o.region && postal_code == o.postal_code && income == o.income && net_worth == o.net_worth && reg_cf_prior_offerings_amount == o.reg_cf_prior_offerings_amount && trustee_first_name == o.trustee_first_name && trustee_last_name == o.trustee_last_name && trustee_suffix == o.trustee_suffix && trustee_country == o.trustee_country && trustee_street_address == o.trustee_street_address && trustee_unit2 == o.trustee_unit2 && trustee_city == o.trustee_city && trustee_region == o.trustee_region && trustee_postal_code == o.trustee_postal_code && trustee_date_of_birth == o.trustee_date_of_birth && trustee_taxpayer_id == o.trustee_taxpayer_id end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 485 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
377 378 379 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 377 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
383 384 385 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 383 def hash [us_accredited_category, ca_accredited_investor, name, date, phone_number, country, street_address, unit2, city, region, postal_code, income, net_worth, reg_cf_prior_offerings_amount, trustee_first_name, trustee_last_name, trustee_suffix, trustee_country, trustee_street_address, trustee_unit2, trustee_city, trustee_region, trustee_postal_code, trustee_date_of_birth, trustee_taxpayer_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
306 307 308 309 310 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 306 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
461 462 463 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 461 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 467 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
455 456 457 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 455 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
314 315 316 317 318 319 320 321 |
# File 'lib/DealMakerAPI/models/patch_trust_profile_request.rb', line 314 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' us_accredited_category_validator = EnumAttributeValidator.new('String', ["entity_owned_by_accredited_investors", "broker_or_dealer", "assets_trust", "not_accredited"]) return false unless us_accredited_category_validator.valid?(@us_accredited_category) ca_accredited_investor_validator = EnumAttributeValidator.new('String', ["p", "w"]) return false unless ca_accredited_investor_validator.valid?(@ca_accredited_investor) true end |