Class: DealMakerAPI::UserApi
- Inherits:
-
Object
- Object
- DealMakerAPI::UserApi
- Defined in:
- lib/DealMakerAPI/api/user_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_user(id, opts = {}) ⇒ V1EntitiesUser
Get user by User ID Get a single user using the User ID.
-
#get_user_with_http_info(id, opts = {}) ⇒ Array<(V1EntitiesUser, Integer, Hash)>
Get user by User ID Get a single user using the User ID.
-
#initialize(api_client = ApiClient.default) ⇒ UserApi
constructor
A new instance of UserApi.
-
#update_user_password(id, update_user_password_request, opts = {}) ⇒ V1EntitiesUser
Update user password Update user password.
-
#update_user_password_with_http_info(id, update_user_password_request, opts = {}) ⇒ Array<(V1EntitiesUser, Integer, Hash)>
Update user password Update user password.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_user(id, opts = {}) ⇒ V1EntitiesUser
Get user by User ID Get a single user using the User ID
27 28 29 30 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 27 def get_user(id, opts = {}) data, _status_code, _headers = get_user_with_http_info(id, opts) data end |
#get_user_with_http_info(id, opts = {}) ⇒ Array<(V1EntitiesUser, Integer, Hash)>
Get user by User ID Get a single user using the User ID
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 37 def get_user_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.get_user ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling UserApi.get_user" end # resource path local_var_path = '/users/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1EntitiesUser' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.get_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#get_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_user_password(id, update_user_password_request, opts = {}) ⇒ V1EntitiesUser
Update user password Update user password
91 92 93 94 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 91 def update_user_password(id, update_user_password_request, opts = {}) data, _status_code, _headers = update_user_password_with_http_info(id, update_user_password_request, opts) data end |
#update_user_password_with_http_info(id, update_user_password_request, opts = {}) ⇒ Array<(V1EntitiesUser, Integer, Hash)>
Update user password Update user password
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/DealMakerAPI/api/user_api.rb', line 102 def update_user_password_with_http_info(id, update_user_password_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.update_user_password ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling UserApi.update_user_password" end # verify the required parameter 'update_user_password_request' is set if @api_client.config.client_side_validation && update_user_password_request.nil? fail ArgumentError, "Missing the required parameter 'update_user_password_request' when calling UserApi.update_user_password" end # resource path local_var_path = '/users/{id}/update_password'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_user_password_request) # return_type return_type = opts[:debug_return_type] || 'V1EntitiesUser' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UserApi.update_user_password", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#update_user_password\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |